gedidb.L4CGranule
=================

.. currentmodule:: gedidb

.. autoclass:: L4CGranule

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~L4CGranule.__init__
      ~L4CGranule.beam
      ~L4CGranule.build_virtual_dataset
      ~L4CGranule.clear
      ~L4CGranule.close
      ~L4CGranule.copy
      ~L4CGranule.create_dataset
      ~L4CGranule.create_dataset_like
      ~L4CGranule.create_group
      ~L4CGranule.create_virtual_dataset
      ~L4CGranule.flush
      ~L4CGranule.get
      ~L4CGranule.items
      ~L4CGranule.iter_beams
      ~L4CGranule.keys
      ~L4CGranule.list_beams
      ~L4CGranule.move
      ~L4CGranule.pop
      ~L4CGranule.popitem
      ~L4CGranule.require_dataset
      ~L4CGranule.require_group
      ~L4CGranule.setdefault
      ~L4CGranule.update
      ~L4CGranule.validate_beam_name
      ~L4CGranule.values
      ~L4CGranule.visit
      ~L4CGranule.visit_links
      ~L4CGranule.visititems
      ~L4CGranule.visititems_links
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~L4CGranule.abstract
      ~L4CGranule.attrs
      ~L4CGranule.driver
      ~L4CGranule.file
      ~L4CGranule.filename
      ~L4CGranule.filename_metadata
      ~L4CGranule.id
      ~L4CGranule.libver
      ~L4CGranule.meta_block_size
      ~L4CGranule.mode
      ~L4CGranule.n_beams
      ~L4CGranule.name
      ~L4CGranule.parent
      ~L4CGranule.product
      ~L4CGranule.ref
      ~L4CGranule.regionref
      ~L4CGranule.start_datetime
      ~L4CGranule.swmr_mode
      ~L4CGranule.userblock_size
      ~L4CGranule.uuid
      ~L4CGranule.version_granule
      ~L4CGranule.version_product
   
   